package com.module.breeze

import android.content.Context
import android.content.Intent
import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.activity.enableEdgeToEdge
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.text.KeyboardOptions
import androidx.compose.material.icons.outlined.Home
import androidx.compose.material.icons.outlined.Map
import androidx.compose.material3.Icon
import androidx.compose.material3.ModalBottomSheet
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Text
import androidx.compose.material3.TextField
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.text.input.KeyboardType
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import com.module.breeze.ui.theme.BreezeTheme
import java.nio.file.WatchEvent

class SettingsActivity : ComponentActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        enableEdgeToEdge()
        setContent {
            BreezeTheme {
                Scaffold(modifier = Modifier.fillMaxSize()) { innerPadding ->
                    Settings(
                        modifier = Modifier.padding(innerPadding)
                    )
                }
            }
        }
    }

    companion object {
        fun openHome(ctx: Context) {
            var intent = Intent(ctx, MainActivity::class.java)
            ctx.startActivity(intent)
        }
    }
}

@Composable
fun Settings(modifier: Modifier = Modifier) {
    val ctx = LocalContext.current
    Navigation(iconStyle.Home, "Home Icon", onClick = {
       SettingsActivity.openHome(ctx)
    })
    Column(
        modifier = Modifier.fillMaxSize(),
        verticalArrangement = Arrangement.Center,
        horizontalAlignment = Alignment.CenterHorizontally
    )
    {
        Row(
            verticalAlignment = Alignment.CenterVertically,
            modifier = Modifier.padding(16.dp)
        )
        {
            Icon(
                imageVector = iconStyle.Map,
                contentDescription = "Configured Locations Icon",
                modifier = Modifier.size(40.dp)
            )
            Text(
                text = "Configured Locations",
                fontWeight = breezeFontWeight,
                fontSize = 22.sp
            )
        }
        ConfiguredLocationDay("Monday")
        ConfiguredLocationDay("Tuesday")
        ConfiguredLocationDay("Wednesday")
        ConfiguredLocationDay("Thursday")
        ConfiguredLocationDay("Friday")
        ConfiguredLocationDay("Saturday")
        ConfiguredLocationDay("Sunday")
    }
}

@Preview(showBackground = true)
@Composable
fun GreetingPreview2() {
    BreezeTheme {
        Settings()
    }
}

@Composable
fun ConfiguredLocationDay(dayName: String = "day") {
    Row(
        verticalAlignment = Alignment.CenterVertically,
        modifier = Modifier.padding(0.dp, 4.dp)
    ) {
        Text(
            text = dayName,
            fontWeight = breezeFontWeight,
            modifier = Modifier.width(100.dp)
        )
        TextField(
            value = "0000",
            onValueChange = {},
            label = { Text("PLZ") },
            keyboardOptions = KeyboardOptions(keyboardType = KeyboardType.Number),
            modifier = Modifier.width(110.dp)
        )
    }
}